@@ -115,7 +115,9 @@ estfun.ivreg <- function (x, ...)
 
 #' @rdname ivregMethods
 #' @exportS3Method sandwich::vcovHC
-vcovHC.ivreg <- function (x, ...) {
+vcovHC.ivreg <- function (x, component = "stage2", ...) {
+    component <- match.arg(component, c("stage2", "stage1"))
+    if(component == "stage1") stop("vcovHC() is not yet implemented for stage1 component")
     class(x) <- c("ivreg_projected", "ivreg")
     sandwich::vcovHC.default(x, ...)
 }
@@ -174,8 +176,8 @@ model.matrix.ivreg_projected <- function(object, ...) model.matrix.ivreg(object,
 #' for \code{residuals}, one of \code{"response"} (the default), \code{"projected"}, \code{"regressors"},
 #' \code{"working"}, \code{"deviance"}, \code{"pearson"}, or \code{"partial"}; 
 #' \code{type = "working"} and \code{"response"} are equivalent, as are 
-#' \code{type = "deviance"} and \code{"pearson"}; for \code{weights}, \code{"variance"} (the default)
-#' for invariance-variance weights (which is \code{NULL} for an unweighted fit) 
+#' \code{type = "deviance"} and \code{"pearson"}; for \code{weights}, \code{"working"} (or equivalently
+#' \code{"variance"}, the default) for invariance-variance weights (which is \code{NULL} for an unweighted fit) 
 #' or \code{"robustness"} for robustness weights (available for M or MM estimation).
 #' @param se.fit Compute standard errors of predicted values (default \code{FALSE}).
 #' @param interval Type of interval to compute for predicted values: \code{"none"} (the default),
@@ -435,7 +437,7 @@ qr.ivreg <- function(x, ...){
 
 #' @rdname ivregMethods
 #' @export
-weights.ivreg <- function(object, type=c("variance", "robustness"), ...){
-  type <- match.arg(type, c("variance", "robustness"))
-  if (type == "variance") object$weights else object$rweights
+weights.ivreg <- function(object, type = c("working", "variance", "robustness"), ...){
+  type <- match.arg(type, c("working", "variance", "robustness"))
+  if (type %in% c("working", "variance")) object$weights else object$rweights
 }
